pub struct AdjustmentItem {
    pub quantity: Option<String>,
    pub per_unit_amount: Option<Box<Currency>>,
    pub total_amount: Option<Box<Currency>>,
    pub seller_sku: Option<String>,
    pub fn_sku: Option<String>,
    pub product_description: Option<String>,
    pub ASIN: Option<String>,
}
AdjustmentItem : An item in an adjustment to the seller’s account.

Fields

quantity: Option<String>

Represents the number of units in the seller’s inventory when the AdustmentType is FBAInventoryReimbursement.

per_unit_amount: Option<Box<Currency>>total_amount: Option<Box<Currency>>seller_sku: Option<String>

The seller SKU of the item. The seller SKU is qualified by the seller’s seller ID, which is included with every call to the Selling Partner API.

fn_sku: Option<String>

A unique identifier assigned to products stored in and fulfilled from a fulfillment center.

product_description: Option<String>

A short description of the item.

ASIN: Option<String>

The Amazon Standard Identification Number (ASIN) of the item.

Implementations

An item in an adjustment to the seller’s account.